Learn R Programming

mrbin (version 1.9.5)

createAnnotationList: A function for creating annotation lists.

Description

This function creates a matrix of peak positions for use with the annotatemrbin function

Usage

createAnnotationList(
  metaboliteNames,
  binwidth = 0.01,
  binheight = 1,
  verbose = TRUE
)

Value

A numeric matrix, the first columns containing metabolite names and the first row being a header. Each row belongs to one unique metabolite signal (left, right, top, bottom borders). Row names are metabolite names.

Arguments

metaboliteNames

Vector of metabolite names

binwidth

Full width of each bin. Will only be used if mrbinObject is a matrix

binheight

Full height of each bin. Will only be used if mrbinObject is a matrix and dimension is set to "2D"

verbose

Should outputs be shown or suppressed?

Examples

Run this code
resetEnv()#clean up previous data from the package environment 

Run the code above in your browser using DataLab