A numeric matrix, the first columns containing metabolite names and the first row being a header. Each row belongs to one unique metabolite signal (left, right, top, bottom borders). Row names are metabolite names.
Arguments
metaboliteNames
Vector of metabolite names
binwidth
Full width of each bin. Will only be used if mrbinObject is a matrix
binheight
Full height of each bin. Will only be used if mrbinObject is a matrix and dimension is set to "2D"